@@ -45,7 +45,7 @@ static GtkWidget *cred_dialog;
 static void zenity_about_dialog_response (GtkWidget *widget, int response, gpointer data);
 
 /* Sync with the people in the THANKS file */
-static const gchar *author_credits[] = {
+static const gchar *const author_credits[] = {
   "Authors",
   "=======",
   "Glynn Foster <glynn foster sun com>",
@@ -91,6 +91,7 @@ static const gchar *author_credits[] = {
   "Tom Tromey  <tromey redhat com>",
   "Yann  <bloch iie cnam fr>",
   "Norman Rasmussen <normanr gmail com>",
+  "Benoît Dejean <tazforever dlfp org>",
   "",
   "And all the translators that rock my world",
   "==========================================",
@@ -169,10 +170,27 @@ static const gchar *author_credits[] = {
   "Daniel Yacob  <locales geez org>",
   "Funda Wang <fundawang linux net cn>",
   "Alexander Winston  <alexander winston comcast net>",
+  "Theppitak Karoonboonyanan <thep linux thai net>",
+  "Martin Willemoes Hansen <mwh sysrq dk>",
+  "Ignacio Casal Quinteiro <nacho.resa gmail com>",
+  "Pawan Chitrakar <pawan nplinux org>",
+  "Rajesh Ranjan <rajeshkajha yahoo org>",
+  "Vladimir Petkov <vpetkov i-space org>",
+  "Abduxukur Abdurixit <abduxukur.abdurixit t-systems ch>",
+  "Adi Attar <aattar cvs gnome org>",
+  "Steve Murphy <murf e-tools com>",
+  "Josep Puigdemont <josep imatge-sintetica com>",
+  "Adam Weinberger <adamw gnome org>",
+  "Ivar Smolin <okul linux ee>",
+  "Jens Seidel <jensseidel users sf net>",
+  "Benoît Dejean <tazforever dlfp org>",
+  "Yair Hershkovitz <yairhr gmail com>",
+  "Clytie Siddall <clytie riverland net au>",
+  "Ilkka Tuohela <hile iki fi>",
   NULL
 };
 
-gchar *translator_credits;
+static gchar *translator_credits;
 
 static gint
 zenity_move_clothes_event (GnomeCanvasItem *item, 
@@ -230,7 +248,7 @@ typedef struct
   gdouble x, y;
 } MonkClothes;
 
-static MonkClothes monk_clothes[] = {
+static const MonkClothes monk_clothes[] = {
   {"gnome-tshirt.png", 30.0, 20.0},
   {"sunglasses.png", ZENITY_CANVAS_X - 100.0 , ZENITY_CANVAS_Y - 150.0 },
   {"surfboard.png", 30.0, ZENITY_CANVAS_Y - 200.0},
@@ -243,7 +261,7 @@ zenity_create_clothes (GtkWidget *canvas_board)
   GdkPixbuf *pixbuf;
   GnomeCanvasItem *canvas_item;
   gchar *pixbuf_path;
-  gint i;
+  size_t i;
 
   for (i = 0; i < G_N_ELEMENTS (monk_clothes); i++) {
     pixbuf_path = g_strconcat (ZENITY_CLOTHES_PATH, monk_clothes[i].filename, NULL); 
@@ -545,7 +563,6 @@ static void
 zenity_about_dialog_response (GtkWidget *widget, int response, gpointer data)
 {
   ZenityData *zen_data = data;
-  GError *error = NULL;
 
   switch (response) {
     case GTK_RESPONSE_OK:
